==> kubernetes-model-1.0.31-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class PersistentVolumeClaimStatusFluentImpl<T extends PersistentVolumeClaimStatusFluent<T>> extends BaseFluent<T> implements PersistentVolumeClaimStatusFluent<T>{

     List<String> accessModes = new ArrayList();     Map<String, Quantity> capacity = new HashMap();     String phase;     Map<String, Object> additionalProperties = new HashMap();

    public T addToAccessModes( String ...items){
    for (String item : items) {this.accessModes.add(item);} return (T)this;
    }
    public T removeFromAccessModes( String ...items){
    for (String item : items) {this.accessModes.remove(item);} return (T)this;
    }
    public List<String> getAccessModes(){
    return this.accessModes;
    }
    public T withAccessModes( List<String> accessModes){
    this.accessModes.clear();if (accessModes != null) {for (String item : accessModes){this.addToAccessModes(item);}} return (T) this;
    }
    public T withAccessModes( String ...accessModes){
    this.accessModes.clear(); if (accessModes != null) {for (String item :accessModes){ this.addToAccessModes(item);}} return (T) this;
    }
    public T addToCapacity( String key,  Quantity value){
    if(key != null && value != null) {this.capacity.put(key, value);} return (T)this;
    }
    public T addToCapacity( Map<String, Quantity> map){
    if(map != null) { this.capacity.putAll(map);} return (T)this;
    }
    public T removeFromCapacity( String key){
    if(key != null) {this.capacity.remove(key);} return (T)this;
    }
    public T removeFromCapacity( Map<String, Quantity> map){
    if(map != null) { for(Object key : map.keySet()) {this.capacity.remove(key);}} return (T)this;
    }
    public Map<String, Quantity> getCapacity(){
    return this.capacity;
    }
    public T withCapacity( Map<String, Quantity> capacity){
    this.capacity.clear();if (capacity != null) {this.capacity.putAll(capacity);} return (T) this;
    }
    public String getPhase(){
    return this.phase;
    }
    public T withPhase( String phase){
    this.phase=phase; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimStatusFluentImpl that = (PersistentVolumeClaimStatusFluentImpl) o;
if (accessModes != null ? !accessModes.equals(that.accessModes) :that.accessModes != null) return false;
if (capacity != null ? !capacity.equals(that.capacity) :that.capacity != null) return false;
if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.36-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class PersistentVolumeClaimStatusFluentImpl<T extends PersistentVolumeClaimStatusFluent<T>> extends BaseFluent<T> implements PersistentVolumeClaimStatusFluent<T>{

     List<String> accessModes = new ArrayList();     Map<String, Quantity> capacity = new HashMap();     String phase;     Map<String, Object> additionalProperties = new HashMap();
public PersistentVolumeClaimStatusFluentImpl(){
    
}
public PersistentVolumeClaimStatusFluentImpl( PersistentVolumeClaimStatus instance ){
    this.withAccessModes(instance.getAccessModes()); this.withCapacity(instance.getCapacity()); this.withPhase(instance.getPhase()); 
}

    public T addToAccessModes( String ...items){
    for (String item : items) {this.accessModes.add(item);} return (T)this;
    }
    public T removeFromAccessModes( String ...items){
    for (String item : items) {this.accessModes.remove(item);} return (T)this;
    }
    public List<String> getAccessModes(){
    return this.accessModes;
    }
    public T withAccessModes( List<String> accessModes){
    this.accessModes.clear();if (accessModes != null) {for (String item : accessModes){this.addToAccessModes(item);}} return (T) this;
    }
    public T withAccessModes( String ...accessModes){
    this.accessModes.clear(); if (accessModes != null) {for (String item :accessModes){ this.addToAccessModes(item);}} return (T) this;
    }
    public T addToCapacity( String key,  Quantity value){
    if(key != null && value != null) {this.capacity.put(key, value);} return (T)this;
    }
    public T addToCapacity( Map<String, Quantity> map){
    if(map != null) { this.capacity.putAll(map);} return (T)this;
    }
    public T removeFromCapacity( String key){
    if(key != null) {this.capacity.remove(key);} return (T)this;
    }
    public T removeFromCapacity( Map<String, Quantity> map){
    if(map != null) { for(Object key : map.keySet()) {this.capacity.remove(key);}} return (T)this;
    }
    public Map<String, Quantity> getCapacity(){
    return this.capacity;
    }
    public T withCapacity( Map<String, Quantity> capacity){
    this.capacity.clear();if (capacity != null) {this.capacity.putAll(capacity);} return (T) this;
    }
    public String getPhase(){
    return this.phase;
    }
    public T withPhase( String phase){
    this.phase=phase; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimStatusFluentImpl that = (PersistentVolumeClaimStatusFluentImpl) o;
if (accessModes != null ? !accessModes.equals(that.accessModes) :that.accessModes != null) return false;
if (capacity != null ? !capacity.equals(that.capacity) :that.capacity != null) return false;
if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
